#
# spec file for package libqt5-qtlocation
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Internal QML imports of examples
%global __requires_exclude qmlimport\\((Local|Qt\\.GeoJson|WeatherInfo).*

%define qt5_snapshot 1
%define libname libQt5Positioning5
%define base_name libqt5
%define real_version 5.15.16
%define so_version 5.15.16
%define tar_version qtlocation-everywhere-src-%{version}
Name:           libqt5-qtlocation
Version:        5.15.16+kde7
Release:        1.1
Summary:        Qt 5 Location Library
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/X11
URL:            https://www.qt.io
Source:         %{tar_version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  fdupes
BuildRequires:  libicu-devel
BuildRequires:  libqt5-qtbase-private-headers-devel >= %{real_version}
BuildRequires:  libqt5-qtdeclarative-private-headers-devel >= %{real_version}
%if %{qt5_snapshot}
#to create the forwarding headers
BuildRequires:  perl
%endif
BuildRequires:  pkgconfig
# needed for free, used to tune build parallelism
BuildRequires:  procps
BuildRequires:  xz
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libssl)

%description
The Qt Location API facilitates creating mapping solutions using
the data available from some contemporary location services.

%package -n %{libname}
Summary:        Qt 5 Positioning Library
Group:          Development/Libraries/X11
Recommends:     geoclue2

%description -n %{libname}
The Qt Positioning API gives developers the ability to determine a
position by using a variety of possible sources, including satellite,
WiFi, text file, and so on. That information can then be used to, for
example, determine a position on a map. In addition, satellite
information can be retrieved and area-based monitoring be performed.

%package -n libQt5Location5
Summary:        Qt 5 Location Library
Group:          Development/Libraries/X11

%description -n libQt5Location5
The Qt Location API facilitates creating mapping solutions using
the data available from some contemporary location services.
Using Qt Location, one can

 * access and present map data,
 * support touch gesture on a specific area of the map,
 * query for a specific geographical location and route,
 * add additional layers on top, such as polylines and circles,
 * and search for places and related images.

%package -n libQt5PositioningQuick5
Summary:        Qt5 Positioning Library for Qt Quick
Group:          System/Libraries

%description -n libQt5PositioningQuick5
This library contains glue code for using the Qt Location module in Qt Quick
applications.

%package devel
Summary:        Development files for the Qt5 Location Library
Group:          Development/Libraries/X11
Requires:       %{libname} = %{version}
Requires:       libQt5Location5 = %{version}
Requires:       libQt5PositioningQuick5 = %{version}

%description devel
The Qt Location API facilitates creating mapping solutions using
the data available from some contemporary location services.

This subpackage contains the header files for developing
applications that want to make use of the Qt Location libraries.

%package private-headers-devel
Summary:        Non-ABI stable experimental API for the Qt5 Location Library
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}
Requires:       libqt5-qtbase-private-headers-devel >= %{real_version}
Requires:       libqt5-qtdeclarative-private-headers-devel
BuildArch:      noarch

%description private-headers-devel
This package provides private headers of libqt5-qtlocation that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package examples
Summary:        Qt5 location examples
Group:          Documentation/Other
License:        BSD-3-Clause
Recommends:     %{name}-devel

%description examples
Examples for libqt5-qtlocation module.

%prep
%autosetup -p1 -n %{tar_version}

%build
%if %{qt5_snapshot}
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif

# boo#1158510
%global _lto_cflags %{?_lto_cflags} -ffat-lto-objects

%qmake5

# do not eat all memory (logic from chromium specfile)
jobs="%{?jobs:%{jobs}}"
echo "Available memory:"
cat /proc/meminfo
echo "System limits:"
ulimit -a
if test -n "$jobs" -a "$jobs" -gt 1 ; then
    mem_per_process=900000
    max_mem=$(awk '/MemTotal/ { print $2 }' /proc/meminfo)
    max_jobs="$(($max_mem / $mem_per_process))"
    test "$jobs" -gt "$max_jobs" && jobs="$max_jobs" && echo "Warning: Reducing number of jobs to $max_jobs because of memory limits"
    test "$jobs" -le 0 && jobs=1 && echo "Warning: Do not use the parallel build at all becuse of memory limits"
fi

make -j$jobs VERBOSE=1

%install
%qmake5_install
find %{buildroot} -type f -name "*.la" -delete -print
find %{buildroot}/%{_libdir}/pkgconfig -type f -name '*.pc' -print -exec perl -pi -e 's, -L%{_builddir}/\S+,,g' {} +
# kill .la files
rm -f %{buildroot}%{_libqt5_libdir}/lib*.la

%fdupes %{buildroot}%{_libqt5_examplesdir}/

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig
%post -n libQt5Location5 -p /sbin/ldconfig
%postun -n libQt5Location5 -p /sbin/ldconfig
%post -n libQt5PositioningQuick5 -p /sbin/ldconfig
%postun -n libQt5PositioningQuick5 -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root,755)
%license LICENSE.*
%{_libqt5_libdir}/libQt5Positioning.so.*
%dir %{_libqt5_plugindir}/position
%{_libqt5_plugindir}/position/libqtposition_geoclue.so
%{_libqt5_plugindir}/position/libqtposition_geoclue2.so
%{_libqt5_plugindir}/position/libqtposition_positionpoll.so

%files -n libQt5Location5
%defattr(-,root,root,755)
%license LICENSE.*
%{_libqt5_libdir}/libQt5Location.so.*
%{_libqt5_plugindir}/geoservices/
%{_libqt5_archdatadir}/qml/QtLocation/
%dir %{_libqt5_archdatadir}/qml/Qt/
%dir %{_libqt5_archdatadir}/qml/Qt/labs/
%{_libqt5_archdatadir}/qml/Qt/labs/location/

%files -n libQt5PositioningQuick5
%license LICENSE.*
%{_libqt5_libdir}/libQt5PositioningQuick.so.*
%{_libqt5_archdatadir}/qml/QtPositioning

%files private-headers-devel
%defattr(-,root,root,755)
%license LICENSE.*
%{_libqt5_includedir}/QtPositioning/%{so_version}
%{_libqt5_includedir}/QtLocation/%{so_version}
%{_libqt5_includedir}/QtPositioningQuick/%{so_version}

%files devel
%defattr(-,root,root,755)
%license LICENSE.*
%exclude %{_libqt5_includedir}/QtPositioning/%{so_version}
%exclude %{_libqt5_includedir}/QtLocation/%{so_version}
%exclude %{_libqt5_includedir}/QtPositioningQuick/%{so_version}
%{_libqt5_includedir}/QtPositioning
%{_libqt5_includedir}/QtLocation
%{_libqt5_includedir}/QtPositioningQuick
%{_libqt5_libdir}/cmake/Qt5Positioning
%{_libqt5_libdir}/cmake/Qt5Location
%{_libqt5_libdir}/cmake/Qt5PositioningQuick
%{_libqt5_libdir}/libQt5Positioning.prl
%{_libqt5_libdir}/libQt5Location.prl
%{_libqt5_libdir}/libQt5PositioningQuick.prl
%{_libqt5_libdir}/libQt5Positioning.so
%{_libqt5_libdir}/libQt5Location.so
%{_libqt5_libdir}/libQt5PositioningQuick.so
%{_libqt5_libdir}/pkgconfig/Qt5Positioning.pc
%{_libqt5_libdir}/pkgconfig/Qt5Location.pc
%{_libqt5_libdir}/pkgconfig/Qt5PositioningQuick.pc
%{_libqt5_libdir}/qt5/mkspecs/modules/qt_lib_*.pri

%files examples
%defattr(-,root,root,755)
%license LICENSE.*
%{_libqt5_examplesdir}/

%changelog
* Mon Nov 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.16+kde7, rebased upstream:
  * Android: fix null array when requesting available providers
  * WeatherInfo example: fix a potential crash
  * Bump version to 5.15.16
* Wed Sep  4 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.15+kde7, rebased upstream:
  * Bump version to 5.15.15
  * CoreLocation plugin: introduce RequestAlwaysPermission parameter
* Wed May 29 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.14+kde7, rebased upstream:
  * Doc: Clean up list
  * Don't build geojson_viewer example without qt.labs.location module
  * Bump version to 5.15.14
* Thu May 16 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 5.15.13+kde7:
  * Update mapbox-gl-native (boo#1224376)
* Tue Mar 19 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.13+kde6, rebased upstream:
  * QtPositioning: add GnssStatus support for android plugin
  * Bump version to 5.15.13
* Fri Dec 29 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.12+kde6, rebased upstream:
  * Fix HereMap plugin not supporting authentication via apiKey
  * Fix build of Qt.labs.location QML plugin
  * PositionSource: fix lastKnownPosition request at startup
  * Bump version to 5.15.12
- Drop patches, now upstream:
  * 0001-Fix-build-of-Qt.labs.location-QML-plugin.patch
* Fri Oct  6 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.11+kde4, rebased upstream:
  * Revert "Make location-labs-plugin depend on features.opengl"
  * Add check to getSatInfoFromNmea to avoid undefined behavior
  * Fix undefined behavior in qlocationutils_readGsa()
  * Use std::remove_if + QVector::erase to remove child pipes
  * PositionSource: do not query lastKnownPosition if the source is inactive
  * Android: fix crash on exit when QGeoAreaMonitorPolling is used
- Add patch to fix build of the Qt.labs.location QML plugin:
  * 0001-Fix-build-of-Qt.labs.location-QML-plugin.patch
* Thu Sep 28 2023 Fabian Vogt <fvogt@suse.com>
- Update to version 5.15.10+kde5:
  * Update mapbox-gl-native
* Tue Jun 13 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.10+kde4, rebased upstream:
  * Make location-labs-plugin depend on features.opengl
- Commits dropped by the rebase:
  * Fix build of Qt.labs.location QML plugin
* Fri Apr 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde7, rebased upstream:
  * No code changes
* Mon Mar  6 2023 fvogt@suse.com
- Update to version 5.15.8+kde4:
  * Update mapbox-gl-native
- Drop patches, now upstream:
  * 0001-Add-some-missing-cstdint-inclusions-872.patch
* Fri Mar  3 2023 Fabian Vogt <fvogt@suse.com>
- Add patch to fix build with GCC 13 (boo#1207470):
  * 0001-Add-some-missing-cstdint-inclusions-872.patch
* Mon Jan  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde3, rebased upstream:
  * Fix positioning must be enabled and authorized at startup to work on iOS
  * Fix position handling in geoclue2 plugin
* Thu Nov  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.7+kde3, rebased upstream:
  * No code changes
* Mon Sep 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.6+kde3, rebased upstream:
  * QGeoCoordinate: fix toString() conversion
* Mon Jun 27 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.5+kde3, rebased upstream:
  * Update use of HTTP to HTTPS in esri plugin
  * Fix appendChildNode() call
  * Fix build of Qt.labs.location QML plugin
  * QtPositioning: fix source detection
  * Revert "Update commercial license headers"
  * Allow removal of layers and sources created using parameters in MapboxGL
  * Update commercial license headers
  * Blacklist ReviewModel::test_reset
  * Fix compilation for no opengl builds
- Drop 0001-Revert-Bump-version.patch, it's versioned correctly now
* Wed Aug 25 2021 Christophe Giboudeaux <christophe@krop.fr>
- Recommend installation of geoclue2. The plugin needs the
  GeoClue2 DBus service file.
* Tue Jun 22 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Switch to KDE's maintenance branch
- Update to version 5.15.2+kde6:
  * Simpler fix to crashing Qml Map appearing 2nd+ time
  * Use QLocale::NorwegianBokmal rather than Norwegian
  * Android: fix Location properties
  * Add changes file for Qt 5.15.2
  * Fix crash when showing Map QML comp. for 2nd+ time
  * Bump version
- Add patch to reset version to 5.15.2:
  * 0001-Revert-Bump-version.patch
* Sun Jan 31 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add compatibility with qml-autoreqprov
* Fri Nov 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.2:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.15.2/?h=5.15.2
* Thu Sep 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.15.1/?h=5.15.1
* Thu Jun  4 2020 Andreas Schwab <schwab@suse.de>
- Bump disk constraints to 5G for everyone
* Wed Jun  3 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add ppc in _constraints to avoid  "No space left on device"
* Tue May 26 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0:
  * No changelog available
* Wed May 20 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0-rc2:
  * No changelog available
  * Removed 0001-Fix-build-with-GCC10.patch: contained in upstream
* Wed May  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-rc:
  * New bugfix release
  * For the changes between 5.14.2 and 5.15.0 please see:
    http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.15.0/?h=5.15.0
* Fri Apr 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta4:
  * New bugfix release
  * No changelog available
* Tue Apr 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta3:
  * New bugfix release
  * No changelog available
* Mon Mar 30 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix the build with GCC10 (boo#1158510):
  * 0001-Fix-build-with-GCC10.patch
- Use -ffat-lto-objects (boo#1158510)
- Drop obsolete conditions
- Reorder the spec file.
* Tue Mar 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Feb 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta1:
  * New bugfix release
  * No changelog available
* Wed Feb 19 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-alpha:
  * New feature release
  * For more details please see:
    https://wiki.qt.io/New_Features_in_Qt_5.15
* Mon Jan 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.14.1/?h=v5.14.1
* Tue Dec 17 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update the license tags.
* Thu Dec 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0:
  * New bugfix release
  * For the changes between 5.13.2 and 5.14.0 please see:
    https://code.qt.io/cgit/qt/qtlocation.git/tree/dist/changes-5.14.0?h=v5.14.0
  * For the changes between 5.13.1 and 5.13.2 please see:
    https://code.qt.io/cgit/qt/qtlocation.git/tree/dist/changes-5.13.2?h=v5.14.0
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-rc:
  * New bugfix release
  * No changelog available
  * For more details please see:
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta3:
  * New bugfix release
  * No changelog available
* Thu Oct 24 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta2:
  * New bugfix release
  * No changelog available
* Tue Oct 15 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta1:
  * New bugfix release
  * No changelog available
* Mon Sep 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-alpha:
  * New feature release
  * No changelog available
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Fri Sep  6 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.13.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.13.1/?h=v5.13.1
* Thu Aug  8 2019 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints for ppc64/ppc64le  for  more than 3.5GB disk
  avoid  "No space left on device"
* Wed Jun 19 2019 fabian@ritter-vogt.de
- Update to 5.13.0:
  * New bugfix release
  * No changelog available
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.13.0/?h=5.13
* Tue Jun  4 2019 fabian@ritter-vogt.de
- Update to 5.13.0-rc:
  * New bugfix release
  * No changelog available
* Mon Apr 29 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta2:
  * New bugfix release
  * No changelog available
* Thu Apr 18 2019 fabian@ritter-vogt.de
- Update to 5.12.3:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.12.3/?h=v5.12.3
* Thu Mar 21 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta1:
  * New feature release
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.13.0/?h=5.13
* Thu Mar 14 2019 fabian@ritter-vogt.de
- Update to 5.12.2:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.12.2/?h=5.12.2
* Wed Mar  6 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Disable the gypsy plugin
- Mention all location plugins explicitly
- Move QtPositioning QML plugin to libQt5PositioningQuick5 package
* Fri Feb  1 2019 fabian@ritter-vogt.de
- Update to 5.12.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.12.1/?h=v5.12.1
* Thu Dec  6 2018 fabian@ritter-vogt.de
- Update to 5.12.0:
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.12.0/?h=v5.12.0
* Mon Dec  3 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc2:
  * New bugfix release
  * Only important bugfixes
- Changelog for Qt 5.12.0:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.12.0/?h=5.12.0
* Thu Nov 22 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc:
  * New bugfix release
  * No changelog available
* Thu Nov  8 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta4:
  * New bugfix release
  * No changelog available
* Fri Oct 26 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta3:
  * New bugfix release
  * No changelog available
* Wed Oct 17 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta1:
  * New bugfix release
  * No changelog available
* Tue Oct  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0-alpha:
  * New feature release
  * For more details please see:
  * http://wiki.qt.io/New_Features_in_Qt_5.12
* Fri Sep 21 2018 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.11.2/?h=v5.11.2
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.11.1/?h=v5.11.1
* Sat Jun  9 2018 fabian@ritter-vogt.de
- Mention libQt5PositioningQuick in baselibs.conf
* Tue May 22 2018 fabian@ritter-vogt.de
- Update to 5.11.0
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.11.0/?h=v5.11.0
* Tue May  8 2018 fabian@ritter-vogt.de
- Update to 5.11.0-rc
  * New bugfix release
  * No changelog available
* Mon Apr 23 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta4
  * New bugfix release
  * No changelog available
* Wed Apr 11 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta3
  * New bugfix release
  * No changelog available
* Wed Mar 28 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta2
  * New bugfix release
  * No changelog available
* Tue Mar 13 2018 christophe@krop.fr
- Fix the license tag.
* Thu Mar  1 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta1
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.11.0-beta1/?h=v5.11.0-beta1
* Tue Feb 20 2018 fabian@ritter-vogt.de
- Update to 5.11.0-alpha
  * New feature release
  * For more details please see:
  * https://wiki.qt.io/New_Features_in_Qt_5.11
* Wed Feb 14 2018 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.10.1/?h=v5.10.1
- Use %%license
* Fri Feb  2 2018 dimstar@opensuse.org
- Eliminate build dependency on procps: we only used it to run
  'free', in order to find out how much RAM we have available. We
  can get this information directly from the kernel, from
  /proc/meminfo.
* Fri Dec  8 2017 christophe@krop.fr
- Update the license tag (boo#967696)
* Thu Dec  7 2017 fabian@ritter-vogt.de
- Update to 5.10.0 final
  * New bugfix release
* Sun Dec  3 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 2
  * New bugfix release
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 1
  * New bugfix release
- Add some feature from the Chromium builds to determine the maximum
  allowed parallel processes based on the available memory.
* Sat Nov 25 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details, see:
    http://code.qt.io/cgit/qt/qtlocation.git/tree/dist/changes-5.9.3/?h=v5.9.3
* Fri Nov 17 2017 zaitor@opensuse.org
- Drop pkgconfig(geoclue) BuildRequires: geoclue is obsoleted by
  geoclue2, and it is not used during compilation of this package
  so just drop it.
* Wed Nov 15 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 4
- Contains bugfixes
* Thu Nov  2 2017 tittiatcoke@gmail.com
- Add some feature from the Chromium builds to determine the maximum
  allowed parallel processes based on the available memory.
* Thu Nov  2 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 3
- Contains bugfixes
* Mon Oct 30 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 2
- Contains bugfixes
* Mon Oct 30 2017 fcrozat@suse.com
- Add logic from chromium specfile to limit build parallelism based
  on available memory. Add BuildRequires procps for this.
* Mon Oct  9 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 1
- For more information visit:
    https://blog.qt.io/blog/2017/10/09/qt-5-10-beta-released/
* Sun Oct  8 2017 lbeltrame@kde.org
- Update to 5.9.2
  * For more details please see:
    https://blog.qt.io/blog/2017/10/06/qt-5-9-2-released/
* Mon Sep 25 2017 fabian@ritter-vogt.de
- Update to 5.10 Alpha 1
- For more information visit:
    https://blog.qt.io/blog/2017/09/13/qt-5-10-alpha-released/
* Mon Sep 11 2017 jengelh@inai.de
- Update package descriptions.
- Use find -exec "+" strategy.
* Sat Jul  1 2017 lbeltrame@kde.org
- Update to 5.9.1
  * For more details please see:
    http://blog.qt.io/blog/2017/06/30/qt-5-9-1-released/
* Wed May 31 2017 fabian@ritter-vogt.de
- Update to 5.9.0 final
* Wed May 24 2017 fabian@ritter-vogt.de
- Update to 5.9.0 RC:
  * For more details please see:
    http://lists.qt-project.org/pipermail/announce/2017-May/000115.html
    and https://wiki.qt.io/New_Features_in_Qt_5.9
* Wed Dec 14 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * For more details please see:
    https://blog.qt.io/blog/2016/12/14/qt-5-7-1-released/
    and https://www.qt.io/qt5-7/
* Sat Sep 24 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.qt.io/qt5-7/
* Wed Jun  8 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * For more details please see:
    http://blog.qt.io/blog/2016/06/08/qt-5-6-1-released/
* Fri Mar 18 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    http://blog.qt.io/blog/2016/03/16/qt-5-6-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.6
* Fri Oct 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1
  * For more details please see:
    http://blog.qt.io/blog/2015/10/15/qt-5-5-1-released/
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * For more details please see:
    http://blog.qt.io/blog/2015/07/01/qt-5-5-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.5
- Restore support for gypsy on Leap
* Wed Jun  3 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2
  * Bugfix release, for more details please see:
    http://blog.qt.io/blog/2015/06/02/qt-5-4-2-released/
* Tue Feb 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1
  * For more details please see:
    http://blog.qt.io/blog/2015/02/24/qt-5-4-1-released/
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- Update to 5.4 Final
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/12/10/qt-5-4-released/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
* Thu Nov 27 2014 hrvoje.senjan@gmail.com
- Update to 5.4 RC
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/11/27/qt-5-4-release-candidate-available/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
- New libQt5Location5 subpackage
* Mon Nov  3 2014 hrvoje.senjan@gmail.com
- Don't BuildRequire pkgconfig(gypsy) for SLE
- Downgrade external packages to suggests of the devel package, they
  are private deps
* Tue Sep 16 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2 final
  * No changes since previous snapshot
  * Use official tars
* Thu Sep  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2~git20140904 (r6e39a79):
  * Tip of the bugfix 5.3.2 branch
  * OSX: Fix QGeoPositionInfo attribute values with
    corelocation plug-in
  * Don't hang weatherinfo if position source has an error.
  * Enforce the use of test.source position plug-in
    in auto tests
  * Report error when failing to connect to Geoclue.
  * Add changelog for QtPositioning 5.3.2 release.
  * Fix fitViewportToMapItemsRefine
  * Avoid potential double deletion when handling
    OSM route replies
  * Fix QGeoRouteReplyOsm::networkReplyFinished
  * Fix issues with MapItemView.
  * Fixed symbol clash between sensor and positioning
    plug-in on iOS
  * Fix the names of the plugin factory classes for
    static plugin loading
* Wed Jun 25 2014 hrvoje.senjan@gmail.com
- Update to 5.3.1
  * Bugfix release, for more details please see:
    http://blog.qt.digia.com/blog/2014/06/25/qt-5-3-1-released/
* Mon Jun  2 2014 hrvoje.senjan@gmail.com
- Added baselibs.conf
- Make private headers noarch
* Mon May 19 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 final
  * Minor bugfixes over previous RC
* Thu May  8 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 RC
  * For more details, please see
  http://blog.qt.digia.com/blog/2014/05/08/qt-5-3-release-candidate-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.3
* Tue Mar 25 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 beta
  * New feature release, please see
  http://blog.qt.digia.com/blog/2014/03/25/qt-5-3-beta-released/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.3
* Fri Mar 21 2014 hrvoje.senjan@gmail.com
- Build, and add examples subpackage
* Wed Feb  5 2014 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/02/05/qt-5-2-1-released/
- Remove libtool archives from packages
* Wed Dec 18 2013 hrvoje.senjan@gmail.com
- Initialize libqt5-qtlocation package
